﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.DragDrop;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls.GridView;
using Telerik.Windows.Controls.TreeView;
using Telerik.Windows.Controls;
using System.Collections;

namespace DragDrop_DropToCell
{
	public partial class MainPage : UserControl
	{
		private IEnumerable draggedItems;
		public MainPage()
		{
			InitializeComponent();

			// You can add handlers to any visual parent of the cell, as long as you check the destination
			// and make sure that the routed event comes form a cell.
			RadDragAndDropManager.AddDropQueryHandler(this, OnDropQuery);
			RadDragAndDropManager.AddDropInfoHandler(this, OnDropInfo);

			gvObjects.ItemsSource = BuildSource();
			treeView.ItemsSource = BuildSource();

			
		}

		private void OnDropQuery(object sender, DragDropQueryEventArgs e)
		{
			e.QueryResult = true;
			e.Handled = true;
		}

		private void OnDropInfo(object sender, DragDropEventArgs e)
		{
			var cell = e.Options.Destination as GridViewCell;
			var dragCue = e.Options.DragCue as TreeViewDragCue;

			if (cell != null && dragCue != null)
			{
				var column = cell.Column;

				if (e.Options.Status == DragStatus.DropPossible)
				{
					dragCue.IsDropPossible = true;

					// Here we have the cell as well, but we would distinquish only te column.
					dragCue.DragActionContent = "Drop in " + column.Header + " column";
				}
				else
				{
					dragCue.IsDropPossible = false;
					dragCue.DragActionContent = null;
					dragCue.DragTooltipContent = null;
				}

				if (e.Options.Status == DragStatus.DropComplete)
				{
					// The object has been dropped and we know in which column.
					this.OnDropInColumn(e.Options.Payload as IEnumerable, column);
				}
			}
			else if (dragCue != null)
			{
				if (e.Options.Status == DragStatus.DropPossible)
				{
					dragCue.IsDropPossible = true;
					dragCue.DragActionContent = "Drop in column...";
					dragCue.DragTooltipContent = null;
				}
				else if (e.Options.Status == DragStatus.DropComplete)
				{
					// The object ahs been dropped in the grid, we do not know which column,
					// Let's ask the user:
					// 1. Make the context menu positioning relative to the screen:
					dropQuestionMenu.Placement = Telerik.Windows.Controls.PlacementMode.Absolute;
					dropQuestionMenu.PlacementRectangle = new Rect();

					// 2. So that we can position it easily:
					dropQuestionMenu.HorizontalOffset = e.Options.CurrentDragPoint.X;
					dropQuestionMenu.VerticalOffset = e.Options.CurrentDragPoint.Y;
					
					// 3. Make sure it displays the right columns:
					dropQuestionMenu.ItemsSource = gvObjects.Columns;

					dropQuestionMenu.IsOpen = true;

					draggedItems = e.Options.Payload as IEnumerable;

					// We handle the menu click to see where the items have been dropped.
				}
			}

		}

		private void OnDropInColumn(IEnumerable iEnumerable, GridViewColumn column)
		{
			//Handle a successful drop here.
		}

		private static IList<MyBusinessObject> BuildSource()
		{
			IList<MyBusinessObject> myBusinessobjects = new ObservableCollection<MyBusinessObject>();
			myBusinessobjects.Add(new MyBusinessObject("Europe", 0));
			myBusinessobjects.Add(new MyBusinessObject("Asia", 1));
			myBusinessobjects.Add(new MyBusinessObject("Afrika", 2));
			return myBusinessobjects;
		}

		private void OnMenuItemClick(object sender, Telerik.Windows.RadRoutedEventArgs e)
		{
			var menuItem = e.Source as Control;
			var column = menuItem.DataContext as GridViewColumn;
			this.OnDropInColumn(draggedItems, column);
			draggedItems = null;
		}
	}

	public class MyBusinessObject
	{
		public MyBusinessObject(string continent, int id)
		{
			Id = id;
			Continent = continent;
		}

		public int Id { get; set; }
		public string Continent { get; set; }
	}
}
